// AboutDlg.h
// (c) 2003 exeal

#ifndef _ABOUT_DLG_H_
#define _ABOUT_DLG_H_
#include "..\Manah\Dialog.h"
#include "..\Manah\LinkLabel.h"
using Manah::Windows::Controls::CDialog;
using Manah::Windows::Controls::CLinkLabel;


// CAboutDlg class definition
/////////////////////////////////////////////////////////////////////////////

namespace Alpha {

///	uo[Wv_CAO
class CAboutDlg : public CDialog {
	// f[^o
private:
	CLinkLabel	m_oHomePage;
	CLinkLabel	m_oSourceForge;

	// bZ[Wnh
protected:
	virtual bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);	// WM_COMMAND
	virtual bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);		// WM_INITDIALOG
};

}

#endif /* _ALPHA_DLG_H_ */

/* [EOF] */